# -*- coding: utf-8 -*-
# Copyright (C) 2012 Canonical
#
# Authors:
#  Didier Roche
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation; version 3.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

import os

from collections import defaultdict
from six.moves import range as gen_range


REV_STRING_FORMAT = "Automatic snapshot from revision"
NEW_CHANGELOG_PATTERN = "^{} \(.*\) (?!UNRELEASED)"
REPLACEME_TAG = "0replaceme"
BRANCH_URL = "lp:~/{}/latestsnapshot-{}"
PROPOSED_URL = "lp:~/{}/{}-{}-proposed"

AUTOUPLOAD_CONTROL_TAG = "X-Auto-Uploader:"
NO_REWRITE_VERSION_TAG = "no-rewrite-version"

IGNORECHANGELOG_COMMIT = "#nochangelog"

BOT_DEBFULLNAME = "Ubuntu daily release"
BOT_DEBEMAIL = "ps-jenkins@lists.canonical.com"
home_dir = os.path.expanduser("~")
CU2D_DIR = os.path.join(home_dir, "cu2d")
GNUPG_DIR = CU2D_DIR
if not os.path.isdir(os.path.join(GNUPG_DIR, '.gnupg')):
    GNUPG_DIR = home_dir
COMMON_LAUNCHPAD_CACHE_DIR = os.path.join(CU2D_DIR, "launchpad.cache")

# selected arch for building arch:all packages
VIRTUALIZED_PPA_ARCH = ["i386", "amd64"]

TIME_BETWEEN_PPA_CHECKS = 5 * 60
PPA_TIMEOUT = 20 * 60

PUBLISHER_ARTEFACTS_FILENAME = 'publisher.xml'

OLD_STACK_DIR = 'old'

ROOT_CU2D = os.path.dirname(os.path.dirname(os.path.realpath(__file__)))

STAGING = not os.path.isfile(os.path.expanduser('~/.production'))
PPA_TEAM = 'ci-train-staging-area' if STAGING else 'ci-train-ppa-service'

# for citrain
SUPPORTED_DISTROS = ('ubuntu', 'ubuntu-rtm')
SILO_NAME_LIST = defaultdict(list)
ALL_SILO_NAMES = []
for dist in SUPPORTED_DISTROS:
    for i in gen_range(0, 31):
        siloname = '{}/landing-{:03d}'.format(dist, i)
        SILO_NAME_LIST[dist].append(siloname)
        ALL_SILO_NAMES.append(siloname)
SILO_BUILDPPA_SCHEME = PPA_TEAM + '/{}/{}'
SILO_PACKAGING_RELEASE_COMMIT_MESSAGE = "Releasing {}"
SILOS_DIR = os.path.expanduser('~/silos')
SILO_RSYNCDIR = "~/out"
SILO_STATUS_RSYNCDIR = os.path.expanduser("~/status")
CITRAIN_BINDIR = os.path.join(ROOT_CU2D, 'citrain')

SERIES_VERSION = {
    'precise': '12.04',
    'raring': '13.04',
    'saucy': '13.10',
    'trusty': '14.04',
    '14.09': '14.09',
    'utopic': '14.10',
    'vivid': '15.04',
}
