from cupstream2distro import project
from cupstream2distro.utils import env, os_path_join_safe

from tests.unit import CITrainScriptTestCase

from mock import Mock, call

# Unused import necessary for code coverage reporting
from citrain import prepare_silo
prepare_silo


FAKE_PROJECTS = ['foo', 'bar', 'grill']


class PrepareSiloTestCase(CITrainScriptTestCase):
    scriptname = 'prepare_silo.py'

    def setUp(self):
        super(PrepareSiloTestCase, self).setUp()
        self.clean_source = self.script.clean_source
        self.script.clean_source = Mock()
        env.SILONAME = ''
        project.SILO_DIR = self.script.SILO_DIR = lambda: self.tempdir
        self.script.DotProject.get_all_packages_uploaded.return_value = set()

    def test_clean_removed_sources_none_to_remove(self):
        self.script.clean_removed_sources(FAKE_PROJECTS, FAKE_PROJECTS)
        self.assertFalse(self.script.clean_source.called)

    def test_clean_removed_sources_one_to_remove(self):
        projects = FAKE_PROJECTS + ['old']
        self.script.clean_removed_sources(FAKE_PROJECTS, projects)
        self.script.clean_source.assert_called_once_with('old')

    def test_clean_removed_sources_two_to_remove(self):
        projects = FAKE_PROJECTS + ['old', 'crud']
        self.script.clean_removed_sources(FAKE_PROJECTS, projects)
        self.assertEqual(
            self.script.clean_source.mock_calls,
            [call('crud'), call('old')])

    def test_clean_source(self):
        self.script.glob.glob.return_value = ['a', 'b', 'c']
        self.clean_source('friggle')
        self.assertEqual(
            self.script.shutil.rmtree.mock_calls,
            [call(os_path_join_safe(self.tempdir, 'friggle')),
             call(os_path_join_safe(self.tempdir, 'ubuntu', 'friggle'))])
        self.assertEqual(
            self.script.os.remove.mock_calls,
            [call(self.script.DotProject().filename),
             call('a'), call('b'), call('c'), call('a'), call('b'), call('c')])
